@@ -133,7 +133,8 @@ public:
     Close();
     s_ = ::socket(AF_INET, type, 0);
     UpdateLastError();
-    enabled_events_ = kfRead | kfWrite;
+    if (type != SOCK_STREAM)
+      enabled_events_ = kfRead | kfWrite;
     return s_ != INVALID_SOCKET;
   }
 
@@ -194,6 +195,7 @@ public:
       state_ = CS_CONNECTING;
       enabled_events_ |= kfConnect;
     }
+    enabled_events_ |= kfRead | kfWrite;
     return err;
   }
 
@@ -400,6 +402,7 @@ protected:
 #ifdef POSIX
 class Dispatcher {
 public:
+  virtual ~Dispatcher() {};
   virtual uint32 GetRequestedEvents() = 0;
   virtual void OnPreEvent(uint32 ff) = 0;    
   virtual void OnEvent(uint32 ff, int err) = 0;
