@@ -336,7 +336,7 @@ AsyncHttpsProxySocket::Authenticate(const char * challenge, size_t len,
     cnonce = DIGEST_CNONCE;
 #else
     char buffer[256];
-    sprintf(buffer, "%d", time(0));
+    sprintf(buffer, "%lu", (unsigned long) time(0));
     cnonce = MD5(buffer);
 #endif
     ncount = "00000001";
@@ -792,7 +792,7 @@ void AsyncHttpsProxySocket::ProcessLine(char * data, size_t len) {
     }
   } else if (state_ == PS_LEADER) {
     uint32 code;
-    if (sscanf(data, "HTTP/%*lu.%*lu %lu", &code) != 1) {
+    if (sscanf(data, "HTTP/%*u.%*u %lu", &code) != 1) {
       Error(0);
       return;
     }
