@@ -501,10 +501,10 @@ private:
 //
 
 Connection::Connection(Port* port, size_t index, const Candidate& remote_candidate)
-  : requests_(port->thread()), port_(port), local_candidate_index_(index),
-    remote_candidate_(remote_candidate), read_state_(STATE_READ_TIMEOUT),
-    write_state_(STATE_WRITE_CONNECT), connected_(true), pruned_(false),
-    rtt_(0), rtt_data_points_(0), last_ping_sent_(0), last_ping_received_(0),
+  : port_(port), local_candidate_index_(index), remote_candidate_(remote_candidate),
+    read_state_(STATE_READ_TIMEOUT), write_state_(STATE_WRITE_CONNECT),
+    connected_(true), pruned_(false),requests_(port->thread()), rtt_(0),
+    rtt_data_points_(0), last_ping_sent_(0), last_ping_received_(0),
     recv_total_bytes_(0), recv_bytes_second_(0),
     last_recv_bytes_second_time_((uint32)-1), last_recv_bytes_second_calc_(0),
     sent_total_bytes_(0), sent_bytes_second_(0),
