@@ -153,11 +153,11 @@ private:
 // BasicPortAllocator
 
 BasicPortAllocator::BasicPortAllocator(NetworkManager* network_manager)
-  : network_manager_(network_manager), best_writable_phase_(-1), stun_address_(NULL), relay_address_(NULL) {
+  : network_manager_(network_manager), stun_address_(NULL), relay_address_(NULL), best_writable_phase_(-1) {
 }
 
 BasicPortAllocator::BasicPortAllocator(NetworkManager* network_manager, SocketAddress* stun_address, SocketAddress *relay_address)
-  : network_manager_(network_manager), best_writable_phase_(-1), stun_address_(stun_address), relay_address_(relay_address) {
+  : network_manager_(network_manager), stun_address_(stun_address), relay_address_(relay_address), best_writable_phase_(-1) {
 }
 
 BasicPortAllocator::~BasicPortAllocator() {
