@@ -304,6 +304,8 @@ TunnelSession::OnSessionState(Session* session, Session::State state) {
   case Session::STATE_RECEIVEDTERMINATE:
     OnTerminate();
     break;
+  default:
+    break;
   }
 }
 
@@ -393,7 +395,9 @@ TunnelSession::Read(void* buffer, size_t buffer_len,
       *error = tcp_->GetError();
     return SR_ERROR;
   }
+  // Dead code?
   AdjustClock();
+  return SR_SUCCESS;
 }
 
 StreamResult
@@ -416,7 +420,9 @@ TunnelSession::Write(const void* data, size_t data_len,
       *error = tcp_->GetError();
     return SR_ERROR;
   }
+  // Dead code?
   AdjustClock();
+  return SR_SUCCESS;
 }
 
 void
